@@ -31,7 +31,7 @@
       DATA      CPARAS(11) / 'LFGBG   ' / , LX(11) / .FALSE. /
       DATA      CPARAS(12) / 'LCMCH   ' / , LX(12) / .TRUE. /
       DATA      CPARAS(13) / 'LSTDOT  ' / , LX(13) / .FALSE. /
-      DATA      CPARAS(14) / 'SYSFONT ' / , LX(14) / .FALSE. /
+      DATA      CPARAS(14) / 'LSYSFNT ' / , LX(14) / .FALSE. /
 
 * ---- LONG NAME ----
       DATA      CPARAL(1)  / 'WAIT' /
