@@ -9,7 +9,7 @@
 
       PARAMETER(MAXL=50,MAXS=200)
       DIMENSION BL(10),BS(10),UY1(MAXS),UY2(MAXL),UYT(MAXL)
-      CHARACTER CH(MAXL)*18,CHR*8,CFMT*16,CSGI*3,CSIDE,CHW*16
+      CHARACTER CH(MAXL)*18,CHR*8,CFMT*16,USGI*3,CSIDE,CHW*16
       LOGICAL LRLT,LRGT,LABEL,LEPSL,LCNTL,LUYCHK,LOFF,LSFNT
 
       SAVE
@@ -103,27 +103,16 @@
             WRITE(CH(NBL),'(I1)') INT(BL(IB))
           ELSE
             IF(JTYPE.EQ.1 .AND. NB.NE.1) THEN
-              WRITE(CH(NBL),'(I1,A3)') INT(BL(IB)), USGI(IYCHR)
+              WRITE(CH(NBL),'(I1,A3)') INT(BL(IB)),USGI(IYCHR)
             ELSE
               CH(NBL)=' '
             ENDIF
 
             WRITE(CHR,'(I8)') IP
             CALL CLADJ(CHR)
-            IF(LCNTL) THEN
-*              IF(LSFNT) THEN
-                CH(NBL)(5:18)='10'//'\^{'//CHR(1:LENZ(CHR))
-     +            //'}'
-*              ELSE
-*                CH(NBL)(3:16)='10'//CSGI(ISUP)//CHR(1:LENZ(CHR))
-*     +            //CSGI(IRST)
-*              END IF
-            ELSE
-              CH(NBL)(4:18)='E'//CHR
-            ENDIF
+            CH(NBL)(5:18)='10\^{'//CHR(1:LENZ(CHR))//'}'
             CALL CLADJ(CH(NBL))
           ENDIF
-
         ELSE
           IF(JTYPE.EQ.0 .AND. IB.NE.1) THEN
             WRITE(CH(NBL),'(I1)') INT(BL(IB))
